@@ -313,6 +313,9 @@ def register_templates(directory=None, name=None, hierarchy_end=True):
     luigi.configuration.add_config_path(template)
     if hierarchy_end:
         luigi.configuration.add_config_path("luigi.cfg")
+        env_cfg = os.environ.get("LUIGI_CONFIG_PATH")
+        if env_cfg is not None:
+            luigi.configuration.add_config_path(env_cfg)
 
 
 class set_luigi_config:
